@@ -4,12 +4,12 @@ function (object, model, fit.sills = TRUE, fit.ranges = TRUE,
 {
     if (missing(object)) 
         stop("nothing to fit to")
-	if (!inherits(object, "variogram"))
+	if (!inherits(object, "gstatVariogram"))
 		stop("object should be of class variogram")
     if (missing(model)) 
         stop("no model to fit")
-    if (!inherits(model, "variogram.model"))
-        stop("model should be of class variogram.model (use vgm)")
+    if (!inherits(model, "variogramModel"))
+        stop("model should be of class variogramModel (use vgm)")
     if (fit.method == 5)
     	stop("use function fit.variogram.reml() to use REML")
     if (length(fit.sills) < length(model$model)) 
