@@ -1,4 +1,4 @@
-"plot.variogram" <-
+"plot.gstatVariogram" <-
 function (x, model = NULL, ylim, xlim, xlab = "distance", 
 	ylab = "semivariance", multipanel = TRUE, plot.numbers = FALSE, scales, 
 	ids = x$id, group.id = TRUE, skip, ...) 
@@ -76,3 +76,24 @@ function (x, model = NULL, ylim, xlim, xlab = "distance",
 			ylim = ylim, xlab = xlab, ylab = ylab, labels = labels, model = model, 
 			direction = c(x$dir.hor[1], x$dir.ver[1]), shift = shift, ...)
 }
+
+"plot.variogramMap" <-
+function(x, np = FALSE, skip, ...) {
+	x = x$map
+	if (! inherits(x, "SpatialDataFrameGrid"))
+		stop("x should be of class SpatialDataFrameGrid")
+	if (np)
+		start = 1 
+	else
+		start = 2 
+	idx = seq(start, length(names(x@data))-length(x@coord.names), by=2)
+	n = floor(sqrt(length(idx) * 2))
+    if (missing(skip)) {
+        skip = NULL
+        for (row in n:1)
+            for (col in 1:n)
+                skip = c(skip, row < col)
+    }
+	levelplot(values ~ dx + dy | ind, as.data.frame(stack(x, select = idx)),
+		asp = mapasp(x), layout = c(n,n), skip = skip, ...)
+}
